@@ -147,33 +147,48 @@ getSquadMatchScores <- function (
   squads <- .cleanData(squads)
 
   # get coach master data from API
+  coaches_blacklisted = FALSE
   coaches <-
     purrr::map_df(
       iterations,
       ~ {
-        response <- jsonlite::fromJSON(
-          httr::content(
-            .callAPIlimited(
-              host,
-              base_url = "/v5/customerapi/iterations/",
-              id = .,
-              suffix = "/coaches",
-              token = token
-            ),
-            "text",
-            encoding = "UTF-8"
-          )
-        )$data
+        response <- .callAPIlimited(
+          host,
+          base_url = "/v5/customerapi/iterations/",
+          id = .,
+          suffix = "/coaches",
+          token = token,
+          ignore_403 = TRUE
+        )
 
-        if (base::length(response) > 0) {
-          response <- response %>%
-            jsonlite::flatten()
-        } else {
+        # check status
+        status <- httr::status_code(response)
+
+        if (status == 403) {
+          coaches_blacklisted <<- TRUE
+
+          # insert empty df as response
           response <- base::data.frame(
             id = -1,
             name = "",
             stringsAsFactors = FALSE
           )
+        } else {
+          response <- jsonlite::fromJSON(
+            httr::content(response, "text", encoding = "UTF-8")
+          )$data
+
+          # flatten response
+          if (base::length(response) > 0) {
+            response <- response %>%
+              jsonlite::flatten()
+          } else {
+            response <- base::data.frame(
+              id = -1,
+              name = "",
+              stringsAsFactors = FALSE
+            )
+          }
         }
       }
     ) %>%
@@ -297,19 +312,24 @@ getSquadMatchScores <- function (
       ),
       by = base::c("matchId" = "matchId", "squadId" = "squadId")
     ) %>%
-    dplyr::left_join(
-      dplyr::select(
-        coaches,
-        coachId = .data$id,
-        coachName = .data$name
-      ),
-      by = base::c("coachId" = "coachId")
-    ) %>%
     # fix some column names
     dplyr::rename(
       dateTime = .data$scheduledDate
     )
 
+  # merge events with coaches
+  if (coaches_blacklisted == FALSE) {
+    scores <- scores %>%
+      dplyr::left_join(
+        dplyr::select(
+          coaches,
+          coachId = .data$id,
+          coachName = .data$name
+        ),
+        by = base::c("coachId" = "coachId")
+      )
+  }
+
   # define column order
   order <- c(
     "matchId",
@@ -331,6 +351,11 @@ getSquadMatchScores <- function (
     scores_list$name
   )
 
+  # check if coaches are blacklisted
+  if (coaches_blacklisted) {
+    order <- order[!order %in% c("coachId", "coachName")]
+  }
+
   # select columns
   scores <- scores %>%
     dplyr::select(dplyr::all_of(order))
